@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: mbed.c 283 2013-06-10 17:42:14Z fabian $
+ *  RCS $Id: mbed.c 300 2016-06-13 13:29:58Z fabian $
  *
  *
  * Reimplementation from scratch of mBed (Blackshields et al., 2010;
@@ -306,9 +306,9 @@ SeqToVec(double **ppdSeqVec, mseq_t *prMSeq,
     int iSeqIndex;
     int iSeedIndex;
    /* indices for restoring order */
-    int *restore; 
+    int *restore = NULL; 
     /* sorted copy of piSeeds */
-    int *piSortedSeeds; 
+    int *piSortedSeeds = NULL; 
 
 #if TIMING
     Stopwatch_t *stopwatch = StopwatchCreate();
@@ -446,6 +446,7 @@ SeqToVec(double **ppdSeqVec, mseq_t *prMSeq,
     
     FreeSymMatrix(&prDistmat);
     CKFREE(restore);
+    CKFREE(piSortedSeeds);
 #if TIMING
     StopwatchStop(stopwatch);
     StopwatchDisplay(stdout, "Total time for SeqToVec(): ", stopwatch);
@@ -1267,8 +1268,8 @@ Mbed(tree_t **prMbedTree_p, mseq_t *prMSeq, const int iPairDistType,
         for (iI = 0; iI < prKMeansResult->iNClusters; iI++) {
             for (iJ=0; iJ<prKMeansResult->piNObjsPerCluster[iI]; iJ++) {
                 int iRealIndex = prKMeansResult->ppiObjIndicesPerCluster[iI][iJ];
-                fprintf(pfClust, "Cluster %u: object %u has index %u (=seq %s )\t %s\n",
-                    iI, iJ,  iRealIndex, prMSeq->sqinfo[iRealIndex].name, ppcClusterSplits[iRealIndex]);
+                fprintf(pfClust, "Cluster %u: object %u has index %u (=seq %s %d~len)\t %s\n",
+                        iI, iJ,  iRealIndex, prMSeq->sqinfo[iRealIndex].name, prMSeq->sqinfo[iRealIndex].len, ppcClusterSplits[iRealIndex]);
             }
         }
         fclose(pfClust); pfClust = NULL;
