@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- * RCS $Id: hhhit-C.h 284 2013-06-12 10:10:11Z fabian $
+ * RCS $Id: hhhit-C.h 308 2016-06-13 14:07:35Z fabian $
  */
 
 // hhhit.C
@@ -47,6 +47,7 @@ using std::ofstream;
 #include "hhalignment.h" // class Alignment
 #include "hhhitlist.h"   // class HitList
 #endif
+//#include "new_new.h" /* memory tracking */
 
 #define CALCULATE_MAX6(max, var1, var2, var3, var4, var5, var6, varb) \
 if (var1>var2) { max=var1; varb=STOP;} \
@@ -159,10 +160,10 @@ Hit::Delete()
       delete[] dbfile; dbfile = NULL;
       for (int k=0; k<n_display; k++) 
           {
-              //delete[] sname[k]; sname[k] = NULL;
+              delete[] sname[k]; sname[k] = NULL;  /* this seems to be the long lost piece of memory, FS, 2016-06-09 */
               delete[] seq[k]; seq[k] = NULL;
           }
-      //delete[] sname; sname = NULL;
+      delete[] sname; sname = NULL;  /* this seems to be the long lost piece of memory, FS, 2016-06-09 */
       delete[] seq; seq = NULL;
     }
 }
